Chars class
Utility class for working with character sequences.
Constructors
- Chars()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
charsToString(
Iterable< Char> chars) → String - Converts an iterable of Char objects back to a string.
-
fromString(
String input) → Iterable< Char> - Converts a string to an iterable of Char objects.
-
isVariantSelector(
int rune) → bool - Checks if a Unicode code point is a variant selector.